@@ -79,7 +79,7 @@ open Filter_common
 open Filter_actions
 
 (* Use aliases if this is an old version (< 4.02) of OCaml without a Bytes module *)
-IFNDEF OCAML_WITH_BYTES_MODULE THEN
+IFDEF OCAML_NO_BYTES_MODULE THEN
 module Bytes = String
 ENDIF
 
@@ -661,6 +661,7 @@ let print_some_help groupable_cp _ _ filename _ =
    end;
    () 
 
+IFDEF OCAML_NO_BYTES_MODULE THEN
 let load_file f =
   let ic = open_in f in
   let n = in_channel_length ic in
@@ -668,6 +669,15 @@ let load_file f =
   really_input ic s 0 n;
   close_in ic;
   (s)
+ENDIF
+IFNDEF OCAML_NO_BYTES_MODULE THEN
+let load_file f =
+  let ic = open_in f in
+  let n = in_channel_length ic in
+  let s = really_input_string ic n in
+  close_in ic;
+  (s)
+ENDIF
 
 let check_occurences big_string to_match conf_file message = 
   let regexp = Str.regexp to_match in
